@@ -3,11 +3,6 @@ package Fey::SQL::Insert;
 use strict;
 use warnings;
 
-use Moose::Policy 'MooseX::Policy::SemiAffordanceAccessor';
-use MooseX::StrictConstructor;
-
-with 'Fey::Role::SQL::HasBindParams';
-
 use Fey::Validate
     qw( validate
         validate_pos
@@ -20,6 +15,12 @@ use Fey::Validate
 use overload ();
 use Scalar::Util qw( blessed );
 
+use Moose;
+use MooseX::SemiAffordanceAccessor;
+use MooseX::StrictConstructor;
+
+with 'Fey::Role::SQL::HasBindParams';
+
 
 sub insert { return $_[0] }
 
@@ -178,6 +179,7 @@ sub bind_params
 }
 
 no Moose;
+
 __PACKAGE__->meta()->make_immutable();
 
 1;
